Included Game Modes
===================

This is an Overview over the game modes that currently ship with piqueserver

Scripts
-------

piqueserver\.game\_modes\.arena gamemode
++++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.arena

piqueserver\.game\_modes\.babel gamemode
++++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.babel

piqueserver\.game\_modes\.freeforall gamemode
+++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.freeforall

piqueserver\.game\_modes\.infiltration gamemode
+++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.infiltration

piqueserver\.game\_modes\.onectf gamemode
+++++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.onectf

piqueserver\.game\_modes\.push gamemode
+++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.push

piqueserver\.game\_modes\.tdm gamemode
++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.tdm

piqueserver\.game\_modes\.tow gamemode
++++++++++++++++++++++++++++++++++++++

.. automodule:: piqueserver.game_modes.tow
